<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID mis à jour",
"Invalid request" => "Requête invalide",
"This is an OpenID server endpoint. For more information, see " => "Ce serveur est un point d'accès OpenID. Pour plus d'informations, veuillez consulter",
"Identity: <b>" => "Identité : <b>",
"Realm: <b>" => "Domaine : <b>",
"User: <b>" => "Utilisateur : <b>",
"Login" => "Connexion",
"Error: <b>No user Selected" => "Erreur : <b>Aucun nom d'utilisateur n'a été saisi",
"OpenID" => "OpenID",
"you can authenticate to other sites with this address" => "vous pouvez vous authentifier sur d'autres sites grâce à cette adresse",
"Authorized OpenID provider" => "Fournisseur d'identité OpenID autorisé",
"Your address at Wordpress, Identi.ca, &hellip;" => "Votre adresse Wordpress, Identi.ca, &hellip;"
);
